@@ -116,6 +116,30 @@ class GeoCoord:
         self.__pos__()
         return self
     
+    def __add__(self, other):
+        # other is a scalar
+        return GeoCoord(self.decimal_degree + other)
+    
+    def __iadd__(self, other):
+        # other is a scalar
+        return self.__add__(other)
+    
+    def __radd__(self, other):
+        # other is a scalar
+        return self.__add__(other)
+    
+    def __sub__(self, other):
+        # other is a scalar
+        return self.__add__(-other)
+    
+    def __isub__(self, other):
+        # other is a scalar
+        return self.__sub__(other)
+    
+    def __rsub__(self, other):
+        # other is a scalar
+        return self.__sub__(other)
+    
     def __floor__(self):
         return GeoCoord(math.floor(self.decimal_degree))
     
@@ -262,13 +286,28 @@ class LatLon:
     def __init__(self, lat, lon, name = None):
         '''
         Input:
-            lat (class instance) - an instance of class Latitude. Can be specified directly in
-              the __init__ call for example by calling LatLon(Latitude(5.8), Longitude(162.5))
-            lon (class instance) - an instance of class Longitude
+            lat (class instance or scalar) - an instance of class Latitude or a scalar. A Latitude object
+              can be instantiated directly in the __init__ call for example by calling LatLon(Latitude(5.8), 
+              Longitude(162.5)). If lat is specified as a scalar, the scalar will be assumed to be in 
+              decimal degrees.
+            lon (class instance or scalar) - an instance of class Longitude or a scalar. If lat is
+              specified as a scalar, the scalar will be assumed to be in decimal degrees.
             name (str) - an identifier
         '''
-        self.lat = lat
-        self.lon = lon
+        try:
+            if lat.type() == 'GeoCoord':
+                self.lat = lat
+            else:
+                raise AttributeError
+        except AttributeError:
+            self.lat = Latitude(lat)
+        try:
+            if lon.type() == 'GeoCoord':
+                self.lon = lon
+            else:
+                raise AttributeError
+        except AttributeError:
+            self.lon = Longitude(lon)
         self.name = name
     
     def project(self, projection):
@@ -391,6 +430,10 @@ class LatLon:
     def __iadd__(self, other):
         # other is a GeoVector object
         return self.__add__(other)
+    
+    def __radd__(self, other):
+        # other is a GeoVector object
+        return self.__add__(other)
 
     def __sub__(self, other):
         # if other is a GeoVector, will return LatLon object
@@ -403,12 +446,19 @@ class LatLon:
         # other is a GeoVector object
         return self.__sub__(other)
     
+    def __rsub__(self, other):
+        # other is a GeoVector object
+        return self.__sub__(other)
+    
     def __str__(self):
         return '%s, %s' %(self.lat.__str__(), self.lon.__str__())
     
     def __repr__(self):
         return '%s, %s' %(self.lat.__repr__(), self.lon.__repr__())
     
+    def __complex__(self):
+        return self.complex()
+    
     def type(self):
         '''
         Identifies the object type
@@ -483,6 +533,10 @@ class GeoVector:
         # other is a GeoVector object
         return self.__add__(other)
     
+    def __radd__(self, other):
+        # other is a GeoVector object
+        return self.__add__(other)
+    
     def __sub__(self, other):
         # other is a GeoVector object
         return self.__add__(-other)
@@ -491,6 +545,10 @@ class GeoVector:
         # other is a GeoVector object
         return self.__sub__(other)
     
+    def __rsub__(self, other):
+        # other is a GeoVector object
+        return self.__sub__(other)
+    
     def __cmp__(self, other):
         return cmp(self.magnitude, other.magnitude)
     
@@ -508,6 +566,10 @@ class GeoVector:
         # other is a scalar
         return self.__mul__(other)
     
+    def __rmul__(self, other):
+        # other is a scalar
+        return self.__mul__(other)
+    
     def __div__(self, other):
         # other is a scalar
         return GeoVector(initial_heading = self.theta, distance = self.magnitude / other)
@@ -516,6 +578,10 @@ class GeoVector:
         # other is a scalar
         return self.__div__(other)
     
+    def __rdiv__(self, other):
+        # other is a scalar
+        return self.__div__(other)
+    
     def __str__(self):
         return '%s %s' %(self.theta, self.magnitude)
     
@@ -529,7 +595,9 @@ class GeoVector:
         return 'GeoVector'
 
 def test():
-    palmyra = LatLon(Latitude(5.8833), Longitude(-162.0833)) # Simplest case - initialize from decimal degrees
+    palmyra = LatLon(Latitude(5.8833), Longitude(-162.0833)) # Try instantiating Latitude and Longitude objects in call
+    palmyra = LatLon(5.8833, -162.0833) # Or even simpler - initialize from two scalars expressing decimal degrees
+    palmyra = LatLon(Latitude(degree = 5, minute = 52, second = 59.88), Longitude(degree = -162, minute = -4.998)) # or more complicated!
     print palmyra.to_string('d% %m% %S% %H') # Print coordinates to degree minute second (returns ('5 52 59.88 N', '162 4 59.88 W'))
     palmyra = string2latlon('5 52 59.88 N', '162 4 59.88 W', 'd% %m% %S% %H') # Initialize from more complex string
     print palmyra.to_string('d%_%M') # Print coordinates as degree minutes separated by underscore (returns ('5_52.998', '-162_4.998'))
